pub struct ManagedZonePrivateVisibilityConfig {
pub gke_clusters: Option<Vec<ManagedZonePrivateVisibilityConfigGKECluster>>,
pub kind: Option<String>,
pub networks: Option<Vec<ManagedZonePrivateVisibilityConfigNetwork>>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
gke_clusters: Option<Vec<ManagedZonePrivateVisibilityConfigGKECluster>>The list of Google Kubernetes Engine clusters that can see this zone.
kind: Option<String>no description provided
networks: Option<Vec<ManagedZonePrivateVisibilityConfigNetwork>>The list of VPC networks that can see this zone.