pub struct ManagedZoneServiceDirectoryConfigNamespace {
pub deletion_time: Option<String>,
pub kind: Option<String>,
pub namespace_url: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
deletion_time: Option<String>The time that the namespace backing this zone was deleted; an empty string if it still exists. This is in RFC3339 text format. Output only.
kind: Option<String>no description provided
namespace_url: Option<String>The fully qualified URL of the namespace associated with the zone. Format must be https://servicedirectory.googleapis.com/v1/projects/{project}/locations/{location}/namespaces/{namespace}