pub struct RRSetRoutingPolicy {
pub geo: Option<RRSetRoutingPolicyGeoPolicy>,
pub health_check: Option<String>,
pub kind: Option<String>,
pub primary_backup: Option<RRSetRoutingPolicyPrimaryBackupPolicy>,
pub wrr: Option<RRSetRoutingPolicyWrrPolicy>,
}Expand description
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection.
This type is not used in any activity, and only used as part of another schema.
Fields
geo: Option<RRSetRoutingPolicyGeoPolicy>no description provided
health_check: Option<String>The fully qualified URL of the HealthCheck to use for this RRSetRoutingPolicy. Format this URL like https://www.googleapis.com/compute/v1/projects/{project}/global/healthChecks/{healthCheck}. https://cloud.google.com/compute/docs/reference/rest/v1/healthChecks
kind: Option<String>no description provided
primary_backup: Option<RRSetRoutingPolicyPrimaryBackupPolicy>no description provided
wrr: Option<RRSetRoutingPolicyWrrPolicy>no description provided