pub struct ResourceRecordSetsListResponse {
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub rrsets: Option<Vec<ResourceRecordSet>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list resource record sets (response)
Fields
kind: Option<String>Type of resource.
next_page_token: Option<String>This field indicates that more results are available beyond the last page displayed. To fetch the results, make another list request and use this value as your page token. This lets you retrieve the complete contents of a very large collection one page at a time. However, if the contents of the collection change between the first and last paginated list request, the set of all elements returned are an inconsistent view of the collection. You can’t retrieve a consistent snapshot of a collection larger than the maximum page size.
rrsets: Option<Vec<ResourceRecordSet>>The resource record set resources.