[][src]Struct google_dns1::Project

pub struct Project {
    pub quota: Option<Quota>,
    pub kind: Option<String>,
    pub id: Option<String>,
    pub number: Option<String>,
}

There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

quota: Option<Quota>

no description provided

kind: Option<String>

Identifies what kind of resource this is. Value: the fixed string "dns#project".

id: Option<String>

no description provided

number: Option<String>

no description provided